import { dataSource } from "../../../data-source";
import { newsletterRecipients } from "../../../entity/club/newsletter/newsletterRecipients";
import { member } from "../../../entity/club/member/member";
import InternalException from "../../../exceptions/internalException";

export default abstract class NewsletterRecipientsService {
  /**
   * @description get all newsletterRecipients
   * @returns {Promise<Array<newsletterRecipients>>}
   */
  static async getAll(newsletterId: number): Promise<Array<newsletterRecipients>> {
    return await dataSource
      .getRepository(newsletterRecipients)
      .createQueryBuilder("newsletterRecipients")
      .leftJoinAndSelect("newsletterRecipients.member", "member")
      .leftJoinAndSelect("member.sendNewsletter", "sendNewsletter")
      .leftJoinAndSelect("sendNewsletter.type", "communicationtype")
      .leftJoinAndSelect("newsletterRecipients.newsletter", "newsletter")
      .where("newsletterRecipients.newsletterId = :id", { id: newsletterId })
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("newsletterRecipients not found", err);
      });
  }
}
